#Completed in R version 4.2.1 (2022-06-23 ucrt) [platform: x86_64-w64-mingw32]
#Including the following packages:
library(pROC) #package version 1.18.0
library(AROC) #package version 1.0-4
library(ggplot2) #package version 3.3.6

#3.4. ROC curves and AUC values for SHARE-Cog (Figure 3)

##Calculation of ROC curves
roc1 <- roc(sample_primary$D_MCI_v_SMC_NC, sample_primary$sharecog_w8, direction="<", levels=c(1, 0))
roc2 <- roc(sample_primary$D_MCI_v_NC, sample_primary$sharecog_w8, direction="<", levels=c(1, 0))
roc3 <- roc(sample_primary$MCI_v_D, sample_primary$sharecog_w8, direction=">", levels=c(1, 0))
roc4 <- roc(sample_primary$MCI_v_SMC_NC, sample_primary$sharecog_w8, direction="<", levels=c(1, 0))
roc5 <- roc(sample_primary$MCI_v_NC, sample_primary$sharecog_w8, direction="<", levels=c(1, 0))
roc6 <- roc(sample_primary$D_v_MCI_SMC_NC, sample_primary$sharecog_w8, direction="<", levels=c(1, 0))

##Statistics AUC values with confidence intervals (presented in main text)
round(ci.auc(roc6, conf.level=0.95, method=c("delong")), 2)[c(2,1,3)] #D_v_MCI_SMC_NC
round(ci.auc(roc2, conf.level=0.95, method=c("delong")), 2)[c(2,1,3)] #D_MCI_v_NC
round(ci.auc(roc1, conf.level=0.95, method=c("delong")), 2)[c(2,1,3)] #D_MCI_v_SMC_NC
round(ci.auc(roc5, conf.level=0.95, method=c("delong")), 2)[c(2,1,3)] #MCI_v_NC
round(ci.auc(roc4, conf.level=0.95, method=c("delong")), 2)[c(2,1,3)] #MCI_v_SMC_NC
round(ci.auc(roc3, conf.level=0.95, method=c("delong")), 2)[c(2,1,3)] #MCI_v_D

##Figure 3a
png("output/Figure3a.png", units="cm", width=18, height=18, res=600)
ggroc(list("D vs MCI+SMC+NC"=roc6, "Dementia+MCI vs NC"=roc2, "Dementia+MCI vs SMC+NC"=roc1, "MCI vs Dementia"=roc3,
           "MCI vs NC" = roc5, "MCI vs SMC+NC"=roc4))+ 
  theme(legend.position="top", legend.title= element_blank())+
  coord_fixed(ratio = 1)+ 
  geom_abline(intercept = 1, slope = 1, size = 0.25)
dev.off()

##Figure 3b

##Data preparation (AROC package requires a dataframe with no missing values, and categorical variables should be coded as factors) 
AROC_data1 <- as.data.frame(sample_primary)
AROC_data1$agecat_w8 <- as.factor(AROC_data1$agecat_w8)
AROC_data1$educationcat_w8 <- as.factor(AROC_data1$educationcat_w8)
AROC_data1$female <- as.factor(AROC_data1$female)
AROC_data1$country <- as.factor(AROC_data1$country)
AROC_data1$D_MCI_v_SMC_NC <- as.factor(AROC_data1$D_MCI_v_SMC_NC)
AROC_data1$D_MCI_v_NC <- as.factor(AROC_data1$D_MCI_v_NC)
AROC_data1$MCI_v_D <- as.factor(AROC_data1$MCI_v_D)
AROC_data1$MCI_v_SMC_NC <- as.factor(AROC_data1$MCI_v_SMC_NC)
AROC_data1$MCI_v_NC <- as.factor(AROC_data1$MCI_v_NC)
AROC_data1$D_v_MCI_SMC_NC <- as.factor(AROC_data1$D_v_MCI_SMC_NC)
AROC_data1$sharecog_w8 <- as.numeric(AROC_data1$sharecog_w8)
AROC_data2 <- AROC_data1[!is.na(AROC_data1$D_MCI_v_NC),]
AROC_data3 <- AROC_data1[!is.na(AROC_data1$MCI_v_D),]
AROC_data4 <- AROC_data1[!is.na(AROC_data1$MCI_v_SMC_NC),]
AROC_data5 <- AROC_data1[!is.na(AROC_data1$MCI_v_NC),]
AROC_data6 <- AROC_data1[!is.na(AROC_data1$D_v_MCI_SMC_NC),]

##Calculation of AROC curves (without confidence intervals)
aroc1 <- AROC.sp(formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
               group = "D_MCI_v_SMC_NC", tag.healthy = 1, data = AROC_data1, B = 1) #Do not require a CI for the plot so B (bootstrap resamples) set to 1 to reduce the computational load)
aroc2 <- AROC.sp(formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
               group = "D_MCI_v_NC", tag.healthy = 1, data = AROC_data2, B = 1)
aroc3 <- AROC.sp(formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
               group = "MCI_v_D", tag.healthy = 0, data = AROC_data3, B = 1)
aroc4 <- AROC.sp(formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
               group = "MCI_v_SMC_NC", tag.healthy = 1, data = AROC_data4, B = 1)
aroc5 <- AROC.sp(formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
               group = "MCI_v_NC", tag.healthy = 1, data = AROC_data5, B = 1)
aroc6 <- AROC.sp(formula.healthy = "sharecog_w8 ~ agecat_w8 + educationcat_w8 + female + country",
               group = "D_v_MCI_SMC_NC", tag.healthy = 1, data = AROC_data6, B = 1)

#Dataframe for Figure 3b
F3b_data <- data.frame(name = rep(c("Dementia+MCI vs SMC+NC", "Dementia+MCI vs NC", 
                                    "MCI vs Dementia","MCI vs SMC+NC", 
                                    "MCI vs NC", "D vs MCI+SMC+NC"), each = 101), 
                       x = rep(seq(0, 1, l = 101), 6),
                       y = c(aroc1$ROC[,1], aroc2$ROC[,1],aroc3$ROC[,1], aroc4$ROC[,1], aroc5$ROC[,1], aroc6$ROC[,1]))

##Plotting the AROC curves
png("output/Figure3b.png", units="cm", width=18, height=18, res=600)
ggplot(F3b_data, aes(x = x, y = y)) +
  geom_line(aes(colour = name), size = 0.5)+ 
  labs(x = "specificity", y = "sensitivity")+
  theme(legend.position="top", legend.title= element_blank())+
  coord_fixed(ratio = 1)+ 
  geom_abline(intercept = 0, slope = 1, size = 0.25)+ 
  scale_x_continuous(labels = c("1.00", "0.75", "0.50", "0.25", "0.00"))+
  scale_y_continuous(labels = c("0.00", "0.25", "0.50", "0.75", "1.00"))
dev.off()
